@@ -1,12 +1,12 @@
-import pytest  # type:ignore[import]
+import pytest
 from pydantic import ValidationError
 
 from bo4e.bo.lastgang import Lastgang
 from bo4e.enum.lokationstyp import Lokationstyp
 from bo4e.enum.mengeneinheit import Mengeneinheit
 from bo4e.enum.sparte import Sparte
-from tests.serialization_helper import assert_serialization_roundtrip  # type:ignore[import]
-from tests.test_zeitreihenwert import example_zeitreihenwert  # type:ignore[import]
+from tests.serialization_helper import assert_serialization_roundtrip
+from tests.test_zeitreihenwert import example_zeitreihenwert
 
 
 class TestLastgang:
