@@ -1,4 +1,4 @@
-import pytest  # type:ignore[import]
+import pytest
 from pydantic import ValidationError
 
 from bo4e.bo.preisblattnetznutzung import PreisblattNetznutzung
@@ -7,10 +7,10 @@ from bo4e.enum.kundengruppe import Kundengruppe
 from bo4e.enum.netzebene import Netzebene
 from bo4e.enum.preisstatus import Preisstatus
 from bo4e.enum.sparte import Sparte
-from tests.serialization_helper import assert_serialization_roundtrip  # type:ignore[import]
-from tests.test_marktteilnehmer import example_marktteilnehmer  # type:ignore[import]
-from tests.test_preisposition import example_preisposition  # type:ignore[import]
-from tests.test_zeitraum import example_zeitraum  # type:ignore[import]
+from tests.serialization_helper import assert_serialization_roundtrip
+from tests.test_marktteilnehmer import example_marktteilnehmer
+from tests.test_preisposition import example_preisposition
+from tests.test_zeitraum import example_zeitraum
 
 
 class TestPreisblatt:
